@@ -1,7 +1,7 @@
 use std::iter;
 
 use criterion::{black_box, criterion_group, criterion_main, Criterion};
-use odbc_api::buffers::{try_buffer_from_description, buffer_from_description, BufferDescription};
+use odbc_api::buffers::{buffer_from_description, try_buffer_from_description, BufferDescription};
 
 fn falliable_buffer_allocation(capacity: usize, max_str_len: usize) {
     let description = BufferDescription {
@@ -19,7 +19,6 @@ fn infalliable_buffer_allocation(capacity: usize, max_str_len: usize) {
     buffer_from_description(capacity, iter::once(description));
 }
 
-
 fn criterion_benchmark(c: &mut Criterion) {
     c.bench_function("fallibale buffer allocation", |b| {
         b.iter(|| {
